# DJ Tools
[![image](https://img.shields.io/pypi/v/djtools.svg)](https://pypi.org/project/djtools/)

Please see the [docs](https://a-rich.github.io/DJ-Tools/) for tutorials, how-to guides, conceptual guides, and references!

# Release Plan
* 2.7.15
    - [ ] [Stability issues with requests to the search endpoint of the Spotify API](https://github.com/a-rich/DJ-Tools/issues/58)
    - [ ] [Make Spotify API calls asynchronous](https://github.com/a-rich/DJ-Tools/issues/38)
* 2.8.0
    - [ ] [Create graphic user interface for djtools](https://github.com/a-rich/DJ-Tools/issues/118)
    - [ ] [Derive boolean algebra expressions that generate a given playlist](https://github.com/a-rich/DJ-Tools/issues/106)
    - [ ] [Improve Reddit submission title parsing in order to improve precision and recall of Spotify API search results](https://github.com/a-rich/DJ-Tools/issues/59)

# Contribution
Please see the [CONTRIBUTING](CONTRIBUTING.md)
